<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Шинэ мессеж ирэхэд мэдэгдэл харуулах';
$labels['desktop'] = 'Шинэ мэйл ирэх үед Дэлгэц дээр мэдэгдэл харуулах';
$labels['sound'] = 'Шинэ мэйл ирэхэд дуугарч мэдэгдэх';
$labels['test'] = 'Туршилт';
$labels['title'] = 'Шинэ Захиа!';
$labels['body'] = 'Та шинэ захиа хүлээн авлаа';
$labels['testbody'] = 'Энэ бол туршилтын мэдэгдэл.';
$labels['desktopdisabled'] = 'Таны хөтчийн Дэлгэцийн мэдэгдэл идэвхгүй байна.';
$labels['desktopunsupported'] = 'Таны вэб хөтөч дэлгэцийн мэдэгдэл зөвшөөрөхгүй байна.';
$labels['desktoptimeout'] = 'Дэлгэцийн мэдэгдэл хаах';
