<?php

/*
 +-----------------------------------------------------------------------+
 | Localization file of the Roundcube Webmail New Mail Notifier plugin   |
 |                                                                       |
 | Copyright (C) The Roundcube Dev Team                                  |
 |                                                                       |
 | Licensed under the GNU General Public License version 3 or            |
 | any later version with exceptions for skins & plugins.                |
 | See the README file for a full license statement.                     |
 +-----------------------------------------------------------------------+
*/

$labels['basic'] = 'Показывать в браузере уведомление о приходе нового сообщения';
$labels['desktop'] = 'Показывать на рабочем столе уведомление о приходе нового сообщения';
$labels['sound'] = 'Подавать звуковой сигнал о приходе нового сообщения';
$labels['test'] = 'Проверить';
$labels['title'] = 'Свежая почта!';
$labels['body'] = 'Вы получили новое сообщение.';
$labels['testbody'] = 'Это тестовое уведомление.';
$labels['desktopdisabled'] = 'В Вашем браузере отключены уведомления на рабочем столе.';
$labels['desktopunsupported'] = 'Ваш браузер не поддерживает уведомления на рабочем столе.';
$labels['desktoptimeout'] = 'Закрыть уведомление на рабочем столе';
